==> nordea_analytics-1.8.0-py3-none-any.whl: nordea_analytics/instrument_variable_names.py <==
from enum import Enum


class BenchmarkName(Enum):
    """Benchmark bonds."""

    DE_3M = "DE 3M"
    DE_2Y = "DE 2Y"
    DE_5Y = "DE 5Y"
    DE_10Y = "DE 10Y"
    DE_30Y = "DE 30Y"
    DK_2Y = "DK 2Y"
    DK_5Y = "DK 5Y"
    DK_10Y = "DK 10Y"
    DK_20Y = "DK 20Y"
    DK_30Y = "DK 30Y"
    DK_ARM_1Y = "DK ARM 1Y"
    DK_ARM_3Y = "DK ARM 3Y"
    DK_ARM_5Y = "DK ARM 5Y"
    DK_MTG_30Y = "DK MTG 30Y"
    EU_3M = "EU 3M"
    EU_2Y = "EU 2Y"
    EU_5Y = "EU 5Y"
    EU_10Y = "EU 10Y"
    EU_30Y = "EU 30Y"
    FI_2Y = "FI 2Y"
    FI_5Y = "FI 5Y"
    FI_10Y = "FI 10Y"
    NL_2Y = "NL 2Y"
    NL_5Y = "NL 5Y"
    NL_10Y = "NL 10Y"
    NL_30Y = "NL 3Y"
    NO_3M = "NO 3M"
    NO_6M = "NO 6M"
    NO_9M = "NO 9M"
    NO_1Y = "NO 1Y"
    NO_3Y = "NO 3Y"
    NO_5Y = "NO 5Y"
    NO_10Y = "NO 10Y"
    SE_2Y = "SE 2Y"


class BondIndexName(Enum):
    """Bond indices."""

    DK_Govt = "DK GOVT"
    DK_Govt_CM_2Y = "DK GOVT CM 2Y"
    DK_Govt_CM_3Y = "DK GOVT CM 3Y"
    DK_Govt_CM_5Y = "DK GOVT CM 5Y"
    DK_Govt_CM_6Y = "DK GOVT CM 6Y"
    DK_Govt_CM_7Y = "DK GOVT CM 7Y"
    DK_Mortgage = "DK MORTGAGE"
    DK_Mortgage_CM_2Y = "DK MORTGAGE CM 2Y"
    DK_Mortgage_CM_3Y = "DK MORTGAGE CM 3Y"
    DK_Mortgage_CM_5Y = "DK MORTGAGE CM 5Y"
    DK_Mortgage_Callable = "DK MORTGAGE CALLABLE"
    DK_Mortgage_Callable_CM_3Y = "DK MORTGAGE CALLABLE CM 3Y"
    DK_Mortgage_Callable_CM_5Y = "DK MORTGAGE CALLABLE CM 5Y"
    DK_Mortgage_Callable_CM_7Y = "DK MORTGAGE CALLABLE CM 7Y"
    DK_Noncallable_Mortgage = "DK NON-CALLBL MTG"
    DK_Noncallable_Mortgage_Less_1Y = "DK NON-CALLBL MTG <1Y"
    DK_Noncallable_Mortgage_Greater_1Y = "DK NON-CALLBL MTG >1Y"
    DK_Noncallable_Mortgage_CM_1Y = "DK NON-CALLBL MTG CM 1Y"
    DK_Noncallable_Mortgage_CM_3Y = "DK NON-CALLBL MTG CM 3Y"

==> nordea_analytics-1.10.0-py3-none-any.whl: nordea_analytics/instrument_variable_names.py <==
from enum import Enum


class BenchmarkName(Enum):
    """Benchmark bonds."""

    DE_3M = "DE 3M"
    DE_2Y = "DE 2Y"
    DE_5Y = "DE 5Y"
    DE_10Y = "DE 10Y"
    DE_30Y = "DE 30Y"
    DK_2Y = "DK 2Y"
    DK_5Y = "DK 5Y"
    DK_10Y = "DK 10Y"
    DK_20Y = "DK 20Y"
    DK_30Y = "DK 30Y"
    DK_ARM_1Y = "DK ARM 1Y"
    DK_ARM_3Y = "DK ARM 3Y"
    DK_ARM_5Y = "DK ARM 5Y"
    DK_MTG_30Y = "DK MTG 30Y"
    EU_3M = "EU 3M"
    EU_2Y = "EU 2Y"
    EU_5Y = "EU 5Y"
    EU_10Y = "EU 10Y"
    EU_30Y = "EU 30Y"
    FI_2Y = "FI 2Y"
    FI_5Y = "FI 5Y"
    FI_10Y = "FI 10Y"
    NL_2Y = "NL 2Y"
    NL_5Y = "NL 5Y"
    NL_10Y = "NL 10Y"
    NL_30Y = "NL 3Y"
    NO_3M = "NO 3M"
    NO_6M = "NO 6M"
    NO_9M = "NO 9M"
    NO_1Y = "NO 1Y"
    NO_3Y = "NO 3Y"
    NO_5Y = "NO 5Y"
    NO_10Y = "NO 10Y"
    SE_2Y = "SE 2Y"


class BondIndexName(Enum):
    """Bond indices."""

    DK_Govt = "DK GOVT"
    DK_Govt_CM_2Y = "DK GOVT CM 2Y"
    DK_Govt_CM_3Y = "DK GOVT CM 3Y"
    DK_Govt_CM_5Y = "DK GOVT CM 5Y"
    DK_Govt_CM_6Y = "DK GOVT CM 6Y"
    DK_Govt_CM_7Y = "DK GOVT CM 7Y"
    DK_Mortgage = "DK MORTGAGE"
    DK_Mortgage_CM_2Y = "DK MORTGAGE CM 2Y"
    DK_Mortgage_CM_3Y = "DK MORTGAGE CM 3Y"
    DK_Mortgage_CM_5Y = "DK MORTGAGE CM 5Y"
    DK_Mortgage_Callable = "DK MTG CALLABLE"
    DK_Mortgage_Callable_CM_3Y = "DK MTG CALLABLE CM 3Y"
    DK_Mortgage_Callable_CM_5Y = "DK MTG CALLABLE CM 5Y"
    DK_Mortgage_Callable_CM_7Y = "DK MTG CALLABLE CM 7Y"
    DK_Noncallable_Mortgage = "DK NON-CALLBL MTG"
    DK_Noncallable_Mortgage_Less_1Y = "DK NON-CALLBL MTG <1Y"
    DK_Noncallable_Mortgage_Greater_1Y = "DK NON-CALLBL MTG >1Y"
    DK_Noncallable_Mortgage_CM_1Y = "DK NON-CALLBL MTG CM 1Y"
    DK_Noncallable_Mortgage_CM_3Y = "DK NON-CALLBL MTG CM 3Y"
